/**
 * @license
 * SPDX-License-Identifier: Apache-2.0
 */
import { ResourceUrlPolicy } from '../resource_url_policy.js';
/**
 * A function that can be used to discard a property.
 *
 * @param name The name of the property.
 * @return Whether the property should be discarded.
 */
export declare type PropertyDiscarder = (name: string) => boolean;
/**
 * Sanitizes a CSS string in a `<style>` tag.
 *
 * @param cssText The CSS string to sanitize.
 * @return The sanitized CSS string.
 */
export declare function sanitizeStyleTag(cssText: string, propertyAllowlist: ReadonlySet<string>, functionAllowlist: ReadonlySet<string>, resourceUrlPolicy: ResourceUrlPolicy, allowKeyframes: boolean, propertyDiscarders: PropertyDiscarder[]): string;
/**
 * Sanitizes a CSS string in a `style` attribute.
 *
 * @param cssText The CSS string to sanitize.
 * @return The sanitized CSS string.
 */
export declare function sanitizeStyleAttribute(cssText: string, propertyAllowlist: ReadonlySet<string>, functionAllowlist: ReadonlySet<string>, resourceUrlPolicy: ResourceUrlPolicy, propertyDiscarders: PropertyDiscarder[]): string;
